@@ -17,7 +17,6 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301, USA.
 #
-# $Id: oct-run_regression_test.pl 15022 2016-01-09 04:19:06Z xavier $
 
 use warnings;
 use Getopt::Std;
@@ -410,6 +409,11 @@ while ($_ = <TESTSUITE>) {
 	set_precision($1);
       }
 
+      elsif ( $_ =~ /^ExtraFile\s*:\s*(.*)\s*$/) {
+        $file_cp = dirname($opt_f)."/".$1;
+        $cp_return = system("cp $file_cp $workdir/");
+      } 
+
       elsif ( $_ =~ /^match/ ) {
 	  # FIXME: should we do matches even when execution failed?
 	  if (!$opt_n && $return_value == 0) {
@@ -565,7 +569,10 @@ sub run_match_new {
     print "   Calculated value : ".$value."\n";
     print "   Reference value  : ".$ref_value."\n";
     print "   Difference       : ".abs($ref_value - $value)."\n";
-    print "   Tolerance        : ".$precnum."\n\n";
+    print "   Deviation [%]    : ".(abs($ref_value - $value)/abs($ref_value)*100.0)."\n";
+    print "   Tolerance        : ".$precnum."\n";
+    print "   Tolerance [%]    : ".($precnum/abs($ref_value)*100.0)."\n\n";
+    
   }
 
   return $success;
